@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-09 15:00:05
-@LastEditTime: 2022-04-28 14:03:51
+@LastEditTime: 2022-06-14 16:52:16
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -15,7 +15,6 @@ class HorseracelampListHandler(ClientBaseHandler):
     """
     :description: 获取跑马灯奖品列表
     """
-    @filter_check_params("act_id")
     def get_async(self):
         """
         :description: 获取跑马灯奖品列表
@@ -27,7 +26,7 @@ class HorseracelampListHandler(ClientBaseHandler):
         :last_editors: HuangJianYi
         """
         app_id = self.get_source_app_id()
-        act_id = int(self.get_param("act_id", 0))
+        act_id = self.get_act_id()
         module_id = int(self.get_param("module_id", -1))
         page_size = int(self.get_param("page_size", 30))
         is_search_module = int(self.get_param("is_search_module", 0))
@@ -54,21 +53,21 @@ class SyncPayOrderHandler(ClientBaseHandler):
     """
     :description: 同步淘宝支付订单给用户加资产
     """
-    @filter_check_params("act_id,tb_user_id,login_token")
+    @filter_check_params("login_token",check_user_code=True)
     def get_async(self):
         """
         :description: 同步淘宝支付订单给用户加资产
         :param app_id:应用标识
         :param act_id:活动标识
         :param module_id:活动模块标识
-        :param tb_user_id:用户标识
+        :param user_code:用户标识
         :param login_token:访问令牌
         :return: 
         :last_editors: HuangJianYi
         """
         app_id = self.get_source_app_id()
         open_id = self.get_param("open_id")
-        act_id = int(self.get_param("act_id", 0))
+        act_id = self.get_act_id()
         user_id = self.get_user_id()
         module_id = int(self.get_param("module_id", 0))
         login_token = self.get_param("login_token")
@@ -125,13 +124,13 @@ class PrizeOrderListHandler(ClientBaseHandler):
     """
     :description: 用户奖品订单列表
     """
-    @filter_check_params("act_id")
+    filter_check_params(check_user_code=True)
     def get_async(self):
         """
         :description: 用户奖品订单列表
         :param act_id：活动标识
         :param order_no：订单号
-        :param tb_user_id：用户标识
+        :param user_code：用户标识
         :param user_open_id：open_id
         :param order_status：订单状态（-1未付款-2付款中0未发货1已发货2不予发货3已退款4交易成功）
         :param create_date_start：订单创建时间开始
@@ -144,7 +143,7 @@ class PrizeOrderListHandler(ClientBaseHandler):
         :last_editors: HuangJianYi
         """
         app_id = self.get_source_app_id()
-        act_id = int(self.get_param("act_id", 0))
+        act_id = self.get_act_id()
         user_id = self.get_user_id()
         user_open_id = self.get_param("user_open_id")
         order_status = int(self.get_param("order_status",-10))
@@ -158,7 +157,6 @@ class PrizeOrderListHandler(ClientBaseHandler):
             is_search_roster = True
         page_index = int(self.get_param("page_index", 0))
         page_size = int(self.get_param("page_size", 10))
-
         invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_success({"data": []})
@@ -171,9 +169,10 @@ class PrizeOrderListHandler(ClientBaseHandler):
         prize_roster_sub_table = invoke_result_data.data["prize_roster_sub_table"] if invoke_result_data.data.__contains__("prize_roster_sub_table") else None
 
         order_base_model = OrderBaseModel(context=self)
-        page_info = order_base_model.get_prize_order_list(app_id, act_id, user_id, user_open_id, "", "", "", "", "", order_status, create_date_start, create_date_end, page_size, page_index, order_by, field, is_search_roster=is_search_roster, is_cache=True, condition=condition, params=params, prize_roster_sub_table=prize_roster_sub_table)
+        page_list, total = order_base_model.get_prize_order_list(app_id, act_id, user_id, user_open_id, "", "", "", "", "", order_status, create_date_start, create_date_end, page_size, page_index, order_by, field, is_search_roster=is_search_roster, is_cache=True, condition=condition, params=params, prize_roster_sub_table=prize_roster_sub_table)
         ref_params = {}
-        page_info.data = self.business_process_executed(page_info.data, ref_params)
+        page_info = PageInfo(page_index, page_size, total, self.business_process_executed(page_list, ref_params))
+
         return self.response_json_success(page_info)
 
 
@@ -181,13 +180,13 @@ class PrizeRosterListHandler(ClientBaseHandler):
     """
     :description: 用户中奖记录列表
     """
-    @filter_check_params("act_id,tb_user_id")
+    filter_check_params(check_user_code=True)
     def get_async(self):
         """
         :description: 用户中奖记录列表
         :param act_id：活动标识
         :param module_id：活动模块标识
-        :param user_id：用户标识
+        :param user_code：用户标识
         :param order_no：订单号
         :param goods_type：物品类型（1虚拟2实物）
         :param prize_type：奖品类型(1现货2优惠券3红包4参与奖5预售)
@@ -201,7 +200,7 @@ class PrizeRosterListHandler(ClientBaseHandler):
         """
         app_id = self.get_source_app_id()
         open_id = self.get_param("open_id")
-        act_id = int(self.get_param("act_id", 0))
+        act_id = self.get_act_id()
         module_id = int(self.get_param("module_id", 0))
         user_id = self.get_user_id()
         order_no = self.get_param("order_no")
@@ -239,7 +238,7 @@ class SubmitSkuHandler(ClientBaseHandler):
         :last_editors: HuangJianYi
         """
         app_id = self.get_source_app_id()
-        act_id = int(self.get_param("act_id", 0))
+        act_id = self.get_act_id()
         open_id = self.get_param("open_id")
         user_prize_id = int(self.get_param("user_prize_id"))
         sku_name = self.get_param("sku_name")
@@ -266,11 +265,11 @@ class SelectPrizeOrderHandler(ClientBaseHandler):
     """
     :description: 中奖记录下单
     """
-    @filter_check_params("act_id,tb_user_id,login_token,real_name,telephone")
+    @filter_check_params("login_token,real_name,telephone", check_user_code=True)
     def get_async(self):
         """
         :param act_id：活动标识
-        :param tb_user_id：用户标识
+        :param user_code：用户标识
         :param login_token:用户访问令牌
         :param prize_ids:用户奖品id串，逗号分隔（为空则将所有未下单的奖品进行下单）
         :param real_name:用户名
@@ -284,7 +283,7 @@ class SelectPrizeOrderHandler(ClientBaseHandler):
         :last_editors: HuangJianYi
         """
         app_id = self.get_source_app_id()
-        act_id = int(self.get_param("act_id", 0))
+        act_id = self.get_act_id()
         user_id = self.get_user_id()
         login_token = self.get_param("login_token")
         prize_ids = self.get_param("prize_ids")
@@ -295,6 +294,7 @@ class SelectPrizeOrderHandler(ClientBaseHandler):
         county = self.get_param("county")
         street = self.get_param("street")
         address = self.get_param("address")
+
         order_base_model = OrderBaseModel(context=self)
         invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
