@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-17 11:19:05
-@LastEditTime: 2022-06-01 11:15:38
+@LastEditTime: 2022-06-22 15:24:55
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -14,19 +14,19 @@ class TaskInfoListHandler(ClientBaseHandler):
     """
     :description: 获取任务列表
     """
-    @filter_check_params("act_id,tb_user_id")
+    @filter_check_params(check_user_code=True)
     def get_async(self):
         """
         :description: 获取任务列表
         :param act_id：活动标识
         :param module_id：活动模块标识
-        :param tb_user_id：用户标识
+        :param user_code：用户标识
         :param task_types:任务类型 多个逗号,分隔
         :return: 
         :last_editors: HuangJianYi
         """
         app_id = self.get_source_app_id()
-        act_id = int(self.get_param("act_id", 0))
+        act_id = self.get_act_id()
         user_id = self.get_user_id()
         module_id = int(self.get_param("module_id", 0))
         task_types = self.get_param("task_types")
@@ -51,14 +51,14 @@ class ReceiveRewardHandler(ClientBaseHandler):
     """
     :description: 处理领取任务奖励
     """
-    @filter_check_params("act_id,tb_user_id,login_token")
+    @filter_check_params("login_token", check_user_code=True)
     def get_async(self):
         """
         :description: 处理领取任务奖励
         :param app_id:应用标识
         :param act_id:活动标识
         :param module_id:活动模块标识
-        :param tb_user_id:用户标识
+        :param user_code:用户标识
         :param login_token:访问令牌
         :param task_id:任务标识
         :param task_sub_type:子任务类型
@@ -66,11 +66,12 @@ class ReceiveRewardHandler(ClientBaseHandler):
         :last_editors: HuangJianYi
         """
         app_id = self.get_source_app_id()
-        act_id = int(self.get_param("act_id", 0))
+        act_id = self.get_act_id()
         user_id = self.get_user_id()
         module_id = int(self.get_param("module_id", 0))
         login_token = self.get_param("login_token")
         task_id = int(self.get_param("task_id", 0))
+        task_type = int(self.get_param("task_type", 0))
         task_sub_type = self.get_param("task_sub_type")
         task_base_model = TaskBaseModel(context=self)
         invoke_result_data = self.business_process_executing()
@@ -83,7 +84,7 @@ class ReceiveRewardHandler(ClientBaseHandler):
         continue_request_expire = invoke_result_data.data["continue_request_expire"] if invoke_result_data.data.__contains__("continue_request_expire") else 5
         is_stat = invoke_result_data.data["is_stat"] if invoke_result_data.data.__contains__("is_stat") else True
         info_json = invoke_result_data.data["info_json"] if invoke_result_data.data.__contains__("info_json") else None
-        invoke_result_data = task_base_model.process_receive_reward(app_id, act_id, module_id, user_id, login_token, task_id, task_sub_type, self.__class__.__name__, self.request_code, check_new_user, check_user_nick, continue_request_expire, is_stat, info_json)
+        invoke_result_data = task_base_model.process_receive_reward(app_id, act_id, module_id, user_id, login_token, task_id, task_sub_type, self.__class__.__name__, self.request_code, task_type, check_new_user, check_user_nick, continue_request_expire, is_stat, info_json)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         ref_params = {}
@@ -97,25 +98,25 @@ class FreeGiftHandler(ClientBaseHandler):
     """
     :description: 处理掌柜有礼、新人有礼、免费领取等相似任务
     """
-    @filter_check_params("act_id,tb_user_id,login_token")
+    @filter_check_params("login_token", check_user_code=True)
     def get_async(self):
         """
         :description: 处理掌柜有礼、新人有礼、免费领取等相似任务
         :param app_id:应用标识
         :param act_id:活动标识
         :param module_id:活动模块标识
-        :param tb_user_id:用户标识
+        :param user_code:用户标识
         :param login_token:访问令牌
         :return: 
         :last_editors: HuangJianYi
         """
         app_id = self.get_source_app_id()
-        act_id = int(self.get_param("act_id", 0))
+        act_id = self.get_act_id()
         user_id = self.get_user_id()
         module_id = int(self.get_param("module_id", 0))
         login_token = self.get_param("login_token")
-        task_base_model = TaskBaseModel(context=self)
 
+        task_base_model = TaskBaseModel(context=self)
         invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
@@ -140,25 +141,24 @@ class OneSignHandler(ClientBaseHandler):
     """
     :description: 处理单次签到任务
     """
-    @filter_check_params("act_id,tb_user_id,login_token")
+    @filter_check_params("login_token", check_user_code=True)
     def get_async(self):
         """
         :description: 处理单次签到任务
         :param app_id:应用标识
         :param act_id:活动标识
         :param module_id:活动模块标识
-        :param tb_user_id:用户标识
+        :param user_code:用户标识
         :param login_token:访问令牌
         :return: 
         :last_editors: HuangJianYi
         """
         app_id = self.get_source_app_id()
-        act_id = int(self.get_param("act_id", 0))
+        act_id = self.get_act_id()
         user_id = self.get_user_id()
         module_id = int(self.get_param("module_id", 0))
         login_token = self.get_param("login_token")
         task_base_model = TaskBaseModel(context=self)
-
         invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
@@ -183,25 +183,24 @@ class WeeklySignHandler(ClientBaseHandler):
     """
     :description: 处理每周签到任务
     """
-    @filter_check_params("act_id,tb_user_id,login_token")
+    @filter_check_params("login_token", check_user_code=True)
     def get_async(self):
         """
         :description: 处理每周签到任务
         :param app_id:应用标识
         :param act_id:活动标识
         :param module_id:活动模块标识
-        :param tb_user_id:用户标识
+        :param user_code:用户标识
         :param login_token:访问令牌
         :return: 
         :last_editors: HuangJianYi
         """
         app_id = self.get_source_app_id()
-        act_id = int(self.get_param("act_id", 0))
+        act_id = self.get_act_id()
         user_id = self.get_user_id()
         module_id = int(self.get_param("module_id", 0))
         login_token = self.get_param("login_token")
         task_base_model = TaskBaseModel(context=self)
-
         invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
@@ -226,25 +225,24 @@ class CumulativeSignHandler(ClientBaseHandler):
     """
     :description: 处理累计签到任务
     """
-    @filter_check_params("act_id,tb_user_id,login_token")
+    @filter_check_params("login_token",check_user_code=True)
     def get_async(self):
         """
         :description: 处理累计签到任务
         :param app_id:应用标识
         :param act_id:活动标识
         :param module_id:活动模块标识
-        :param tb_user_id:用户标识
+        :param user_code:用户标识
         :param login_token:访问令牌
         :return: 
         :last_editors: HuangJianYi
         """
         app_id = self.get_source_app_id()
-        act_id = int(self.get_param("act_id", 0))
+        act_id = self.get_act_id()
         user_id = self.get_user_id()
         module_id = int(self.get_param("module_id", 0))
         login_token = self.get_param("login_token")
         task_base_model = TaskBaseModel(context=self)
-
         invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
@@ -269,27 +267,26 @@ class InviteNewUserHandler(ClientBaseHandler):
     """
     :description: 处理邀请用户任务
     """
-    @filter_check_params("act_id,tb_user_id,invite_user_id,login_token")
+    @filter_check_params("invite_user_id,login_token", check_user_code=True)
     def get_async(self):
         """
         :description: 处理邀请新用户任务
         :param app_id:应用标识
         :param act_id:活动标识
         :param module_id:活动模块标识
-        :param tb_user_id:用户标识
+        :param user_code:用户标识
         :param invite_user_id:邀请人用户标识
         :param login_token:访问令牌
         :return: 
         :last_editors: HuangJianYi
         """
         app_id = self.get_source_app_id()
-        act_id = int(self.get_param("act_id", 0))
+        act_id = self.get_act_id()
         user_id = self.get_user_id()
         module_id = int(self.get_param("module_id", 0))
         login_token = self.get_param("login_token")
         from_user_id = int(self.get_param("invite_user_id", 0))
         task_base_model = TaskBaseModel(context=self)
-
         invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
@@ -299,7 +296,7 @@ class InviteNewUserHandler(ClientBaseHandler):
         check_new_user = invoke_result_data.data["check_new_user"] if invoke_result_data.data.__contains__("check_new_user") else True
         continue_request_expire = invoke_result_data.data["continue_request_expire"] if invoke_result_data.data.__contains__("continue_request_expire") else 5
         close_invite_limit = invoke_result_data.data["close_invite_limit"] if invoke_result_data.data.__contains__("close_invite_limit") else False
-        invoke_result_data = task_base_model.process_invite_user(app_id, act_id, module_id, user_id, login_token, from_user_id, self.__class__.__name__, check_user_nick, check_new_user, continue_request_expire, close_invite_limit)
+        invoke_result_data = task_base_model.process_invite_user(app_id, act_id, module_id, user_id, login_token, from_user_id, self.__class__.__name__, self.request_code, check_user_nick, check_new_user, continue_request_expire, close_invite_limit)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         ref_params = {}
@@ -313,27 +310,26 @@ class InviteJoinMemberHandler(ClientBaseHandler):
     """
     :description: 处理邀请加入会员任务
     """
-    @filter_check_params("act_id,tb_user_id,invite_user_id,login_token")
+    @filter_check_params("invite_user_id,login_token", check_user_code=True)
     def get_async(self):
         """
         :description: 处理邀请加入会员任务
         :param app_id:应用标识
         :param act_id:活动标识
         :param module_id:活动模块标识
-        :param tb_user_id:用户标识
+        :param user_code:用户标识
         :param invite_user_id:邀请人用户标识
         :param login_token:访问令牌
         :return: 
         :last_editors: HuangJianYi
         """
         app_id = self.get_source_app_id()
-        act_id = int(self.get_param("act_id", 0))
+        act_id = self.get_act_id()
         user_id = self.get_user_id()
         module_id = int(self.get_param("module_id", 0))
         login_token = self.get_param("login_token")
         from_user_id = int(self.get_param("invite_user_id", 0))
         task_base_model = TaskBaseModel(context=self)
-
         invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
@@ -360,27 +356,26 @@ class CollectGoodsHandler(ClientBaseHandler):
     """
     :description: 处理收藏商品任务
     """
-    @filter_check_params("act_id,tb_user_id,login_token,goods_id")
+    @filter_check_params("login_token,goods_id", check_user_code=True)
     def get_async(self):
         """
         :description: 处理收藏商品任务
         :param app_id:应用标识
         :param act_id:活动标识
         :param module_id:活动模块标识
-        :param tb_user_id:用户标识
+        :param user_code:用户标识
         :param goods_id:商品ID
         :param login_token:访问令牌
         :return: 
         :last_editors: HuangJianYi
         """
         app_id = self.get_source_app_id()
-        act_id = int(self.get_param("act_id", 0))
+        act_id = self.get_act_id()
         user_id = self.get_user_id()
         module_id = int(self.get_param("module_id", 0))
         goods_id = self.get_param("goods_id")
         login_token = self.get_param("login_token")
         task_base_model = TaskBaseModel(context=self)
-
         invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
@@ -402,27 +397,26 @@ class BrowseGoodsHandler(ClientBaseHandler):
     """
     :description: 处理浏览商品任务
     """
-    @filter_check_params("act_id,tb_user_id,login_token,goods_id")
+    @filter_check_params("login_token,goods_id", check_user_code=True)
     def get_async(self):
         """
         :description: 处理浏览商品任务
         :param app_id:应用标识
         :param act_id:活动标识
         :param module_id:活动模块标识
-        :param tb_user_id:用户标识
+        :param user_code:用户标识
         :param goods_id:商品ID
         :param login_token:访问令牌
         :return: 
         :last_editors: HuangJianYi
         """
         app_id = self.get_source_app_id()
-        act_id = int(self.get_param("act_id", 0))
+        act_id = self.get_act_id()
         user_id = self.get_user_id()
         module_id = int(self.get_param("module_id", 0))
         goods_id = self.get_param("goods_id")
         login_token = self.get_param("login_token")
         task_base_model = TaskBaseModel(context=self)
-
         invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
@@ -445,25 +439,24 @@ class FavorStoreHandler(ClientBaseHandler):
     """
     :description: 处理关注店铺
     """
-    @filter_check_params("act_id,tb_user_id,login_token")
+    @filter_check_params("login_token", check_user_code=True)
     def get_async(self):
         """
         :description: 处理关注店铺
         :param app_id:应用标识
         :param act_id:活动标识
         :param module_id:活动模块标识
-        :param tb_user_id:用户标识
+        :param user_code:用户标识
         :param login_token:访问令牌
         :return: 
         :last_editors: HuangJianYi
         """
         app_id = self.get_source_app_id()
-        act_id = int(self.get_param("act_id", 0))
+        act_id = self.get_act_id()
         user_id = self.get_user_id()
         module_id = int(self.get_param("module_id", 0))
         login_token = self.get_param("login_token")
         task_base_model = TaskBaseModel(context=self)
-
         invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
@@ -487,25 +480,24 @@ class JoinMemberHandler(ClientBaseHandler):
     """
     :description: 处理加入店铺会员
     """
-    @filter_check_params("act_id,tb_user_id,login_token")
+    @filter_check_params("login_token", check_user_code=True)
     def get_async(self):
         """
         :description: 处理加入店铺会员
         :param app_id:应用标识
         :param act_id:活动标识
         :param module_id:活动模块标识
-        :param tb_user_id:用户标识
+        :param user_code:用户标识
         :param login_token:访问令牌
         :return: 
         :last_editors: HuangJianYi
         """
         app_id = self.get_source_app_id()
-        act_id = int(self.get_param("act_id", 0))
+        act_id = self.get_act_id()
         user_id = self.get_user_id()
         module_id = int(self.get_param("module_id", 0))
         login_token = self.get_param("login_token")
         task_base_model = TaskBaseModel(context=self)
-
         invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
@@ -533,14 +525,14 @@ class BrowseSiteHandler(ClientBaseHandler):
     """
     :description: 处理浏览网址相关任务 如：浏览店铺、浏览直播间、浏览会场/专题
     """
-    @filter_check_params("act_id,tb_user_id,login_token")
+    @filter_check_params("login_token", check_user_code=True)
     def get_async(self):
         """
         :description: 处理浏览商品任务
         :param app_id:应用标识
         :param act_id:活动标识
         :param module_id:活动模块标识
-        :param tb_user_id:用户标识
+        :param user_code:用户标识
         :param task_type:任务类型
         :param task_sub_type:子任务类型
         :param login_token:访问令牌
@@ -548,14 +540,13 @@ class BrowseSiteHandler(ClientBaseHandler):
         :last_editors: HuangJianYi
         """
         app_id = self.get_source_app_id()
-        act_id = int(self.get_param("act_id", 0))
+        act_id = self.get_act_id()
         user_id = self.get_user_id()
         module_id = int(self.get_param("module_id", 0))
         task_type = int(self.get_param("task_type", 0))
         task_sub_type = self.get_param("task_sub_type")
         login_token = self.get_param("login_token")
         task_base_model = TaskBaseModel(context=self)
-
         invoke_result_data = InvokeResultData()
         if task_type not in [TaskType.browse_store.value,TaskType.browse_live_room.value,TaskType.browse_special_topic.value]:
             invoke_result_data.success = False
@@ -583,25 +574,24 @@ class ShareHandler(ClientBaseHandler):
     """
     :description: 分享奖励任务
     """
-    @filter_check_params("act_id,tb_user_id,login_token")
+    @filter_check_params("login_token", check_user_code=True)
     def get_async(self):
         """
         :description: 分享奖励任务
         :param app_id:应用标识
         :param act_id:活动标识
         :param module_id:活动模块标识
-        :param tb_user_id:用户标识
+        :param user_code:用户标识
         :param login_token:访问令牌
         :return: 
         :last_editors: HuangJianYi
         """
         app_id = self.get_source_app_id()
-        act_id = int(self.get_param("act_id", 0))
+        act_id = self.get_act_id()
         user_id = self.get_user_id()
         module_id = int(self.get_param("module_id", 0))
         login_token = self.get_param("login_token")
         task_base_model = TaskBaseModel(context=self)
-
         invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
