@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-03 15:42:53
-@LastEditTime: 2022-01-21 21:27:46
+@LastEditTime: 2022-06-13 14:29:05
 @LastEditors: HuangJianYi
 @Description: 活动模块
 """
@@ -90,7 +90,6 @@ class UpdateActInfoHandler(ClientBaseHandler):
     """
     :description: 修改活动信息
     """
-    @filter_check_params("act_id")
     def post_async(self):
         """
         :description: 修改活动信息
@@ -126,7 +125,7 @@ class UpdateActInfoHandler(ClientBaseHandler):
         :last_editors: HuangJianYi
         """
         app_id = self.get_app_id()
-        act_id = int(self.get_param("act_id", 0))
+        act_id = self.get_act_id()
         act_name = self.get_param("act_name", None)
         theme_id = int(self.get_param("theme_id", -1))
         is_share = int(self.get_param("is_share", -1))
@@ -211,7 +210,6 @@ class ActInfoHandler(ClientBaseHandler):
     """
     :description: 获取活动信息
     """
-    @filter_check_params("act_id")
     def get_async(self):
         """
         :description: 获取活动信息
@@ -221,7 +219,7 @@ class ActInfoHandler(ClientBaseHandler):
         :last_editors: HuangJianYi
         """
         app_id = self.get_app_id()
-        act_id = int(self.get_param("act_id", 0))
+        act_id = self.get_act_id()
         invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
@@ -244,7 +242,6 @@ class DeleteActInfoHandler(ClientBaseHandler):
     """
     :description: 删除活动
     """
-    @filter_check_params("act_id")
     def get_async(self):
         """
         :description: 删除活动
@@ -254,7 +251,7 @@ class DeleteActInfoHandler(ClientBaseHandler):
         :last_editors: HuangJianYi
         """
         app_id = self.get_app_id()
-        act_id = int(self.get_param("act_id", 0))
+        act_id = self.get_act_id()
         invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
@@ -274,7 +271,6 @@ class ReviewActInfoHandler(ClientBaseHandler):
     """
     :description: 还原活动
     """
-    @filter_check_params("act_id")
     def get_async(self):
         """
         :description: 还原活动
@@ -284,7 +280,7 @@ class ReviewActInfoHandler(ClientBaseHandler):
         :last_editors: HuangJianYi
         """
         app_id = self.get_app_id()
-        act_id = int(self.get_param("act_id", 0))
+        act_id = self.get_act_id()
         invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
@@ -304,7 +300,6 @@ class ReleaseActInfoHandler(ClientBaseHandler):
     """
     :description: 上下架活动
     """
-    @filter_check_params("act_id")
     def get_async(self):
         """
         :description: 上下架活动
@@ -315,7 +310,7 @@ class ReleaseActInfoHandler(ClientBaseHandler):
         :last_editors: HuangJianYi
         """
         app_id = self.get_app_id()
-        act_id = int(self.get_param("act_id", 0))
+        act_id = self.get_act_id()
         is_release = int(self.get_param("is_release", 0))
         invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
@@ -339,7 +334,6 @@ class CreateActQrCodeHandler(ClientBaseHandler):
     def get_async(self):
         """
         :description: 创建活动二维码
-        :param act_id：活动标识
         :return: 活动二维码图片
         :last_editors: HuangJianYi
         """
@@ -353,7 +347,7 @@ class NextProgressHandler(ClientBaseHandler):
     """
     :description: 下一步配置
     """
-    @filter_check_params("act_id,finish_key")
+    @filter_check_params("finish_key")
     def get_async(self):
         """
         :description: 下一步配置
@@ -364,7 +358,7 @@ class NextProgressHandler(ClientBaseHandler):
         :last_editors: HuangJianYi
         """
         app_id = self.get_app_id()
-        act_id = int(self.get_param("act_id", 0))
+        act_id = self.get_act_id()
         finish_key = self.get_param("finish_key")
 
         act_base_model = ActBaseModel(context=self)
