@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-30 15:46:34
-@LastEditTime: 2021-11-29 16:39:08
+@LastEditTime: 2022-06-13 14:31:55
 @LastEditors: HuangJianYi
 @Description: 投放模块
 """
@@ -20,7 +20,6 @@ class InitLaunchGoodsHandler(ClientBaseHandler):
     """
     :description: 初始化商品投放
     """
-    @filter_check_params("act_id")
     def get_async(self):
         """
         :description: 初始化商品投放
@@ -32,13 +31,20 @@ class InitLaunchGoodsHandler(ClientBaseHandler):
         :last_editors: HuangJianYi
         """
         app_id = self.get_app_id()
-        act_id = int(self.get_param("act_id", 0))
+        act_id = self.get_act_id()
         module_id = int(self.get_param("module_id", 0))
         source_types = self.get_param("source_types","1,2")
 
+        invoke_result_data = self.business_process_executing()
+        if invoke_result_data.success == False:
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         online_url = self.get_online_url(act_id, app_id, module_id)
         launch_base_model = LaunchBaseModel(context=self)
         invoke_result_data = launch_base_model.init_launch_goods(app_id, act_id, source_types, online_url)
+        if invoke_result_data.success == False:
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
+        ref_params = {}
+        invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         return self.response_json_success(invoke_result_data.data)
@@ -48,7 +54,6 @@ class ResetLaunchGoodsHandler(ClientBaseHandler):
     """
     :description: 重置商品投放 删除已投放的记录并将活动投放状态改为未投放
     """
-    @filter_check_params("act_id")
     def get_async(self):
         """
         :description: 重置商品投放 删除已投放的记录并将活动投放状态改为未投放
@@ -58,11 +63,18 @@ class ResetLaunchGoodsHandler(ClientBaseHandler):
         :last_editors: HuangJianYi
         """
         app_id = self.get_app_id()
-        act_id = int(self.get_param("act_id", 0))
+        act_id = self.get_act_id()
 
+        invoke_result_data = self.business_process_executing()
+        if invoke_result_data.success == False:
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         ActInfoModel(context=self).update_table("is_launch=0", "app_id=%s and id=%s", params=[app_id, act_id])
         ActBaseModel(context=self)._delete_act_info_dependency_key(app_id, act_id)
         LaunchGoodsModel(context=self).del_entity("app_id=%s and id=%s", params=[app_id, act_id])
+        ref_params = {}
+        invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
+        if invoke_result_data.success == False:
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         return self.response_json_success()
 
 
@@ -80,15 +92,21 @@ class InitLaunchGoodsCallBackHandler(ClientBaseHandler):
         :last_editors: HuangJianYi
         """
         app_id = self.get_app_id()
-        act_id = int(self.get_param("act_id", 0))
+        act_id = self.get_act_id()
         close_goods_id = self.get_param("close_goods_id")
 
+        invoke_result_data = self.business_process_executing()
+        if invoke_result_data.success == False:
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         ActInfoModel(context=self).update_table("is_launch=1", "id=%s", params=act_id)
         ActBaseModel(context=self)._delete_act_info_dependency_key(app_id,act_id)
         if close_goods_id != "":
             close_goods_id_list = list(set(close_goods_id.split(",")))
             LaunchGoodsModel(context=self).update_table("is_launch=0,launch_date=%s", "act_id=%s and "+ SevenHelper.get_condition_by_str_list("goods_id",close_goods_id_list), params=[SevenHelper.get_now_datetime(),act_id])
-
+        ref_params = {}
+        invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
+        if invoke_result_data.success == False:
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         return self.response_json_success()
 
 
@@ -96,7 +114,6 @@ class UpdateLaunchGoodsStatusHandler(ClientBaseHandler):
     """
     :description: 更改投放商品的状态
     """
-    @filter_check_params("act_id")
     def get_async(self):
         """
         :description: 保存更改投放商品的状态
@@ -107,11 +124,18 @@ class UpdateLaunchGoodsStatusHandler(ClientBaseHandler):
         :last_editors: HuangJianYi
         """
         app_id = self.get_app_id()
-        act_id = int(self.get_param("act_id", 0))
+        act_id = self.get_act_id()
         goods_id = self.get_param("update_goods_id")
+
+        invoke_result_data = self.business_process_executing()
+        if invoke_result_data.success == False:
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         if goods_id != "":
             LaunchGoodsModel(context=self).update_table("is_launch=abs(is_launch-1),is_sync=0,launch_date=%s", "app_id=%s and act_id=%s and goods_id=%s", [self.get_now_datetime(), app_id, act_id, goods_id])
-
+        ref_params = {}
+        invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
+        if invoke_result_data.success == False:
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         return self.response_json_success()
 
 
@@ -119,7 +143,6 @@ class LaunchGoodsListHandler(ClientBaseHandler):
     """
     :description: 投放商品列表
     """
-    @filter_check_params("act_id")
     def get_async(self):
         """
         :description: 投放商品列表
@@ -131,12 +154,21 @@ class LaunchGoodsListHandler(ClientBaseHandler):
         :last_editors: HuangJianYi
         """
         app_id = self.get_app_id()
-        act_id = int(self.get_param("act_id", 0))
+        act_id = self.get_act_id()
         page_index = int(self.get_param("page_index", 0))
         page_size = int(self.get_param("page_size", 20))
+        access_token = self.get_access_token()
+
+        invoke_result_data = self.business_process_executing()
+        if invoke_result_data.success == False:
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         launch_base_model = LaunchBaseModel(context=self)
         app_key, app_secret = self.get_app_key_secret()
-        invoke_result_data = launch_base_model.get_launch_goods_list(app_id, act_id, page_size, page_index, self.get_param("access_token"), app_key, app_secret)
+        invoke_result_data = launch_base_model.get_launch_goods_list(app_id, act_id, page_size, page_index, access_token, app_key, app_secret)
+        if invoke_result_data.success == False:
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
+        ref_params = {}
+        invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         return self.response_json_success(invoke_result_data.data)
@@ -146,7 +178,7 @@ class AsyncLaunchGoodsHandler(ClientBaseHandler):
     """
     :description: 同步投放商品（小程序投放-商品绑定/解绑）
     """
-    @filter_check_params("app_id,act_id")
+    @filter_check_params("app_id")
     def get_async(self):
         """
         :description: 同步投放商品（小程序投放-商品绑定/解绑）
@@ -157,13 +189,22 @@ class AsyncLaunchGoodsHandler(ClientBaseHandler):
         :last_editors: HuangJianYi
         """
         app_id = self.get_app_id()
-        act_id = int(self.get_param("act_id", 0))
+        act_id = self.get_act_id()
         module_id = int(self.get_param("module_id", 0))
+        access_token = self.get_access_token()
 
+        invoke_result_data = self.business_process_executing()
+        if invoke_result_data.success == False:
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         online_url = self.get_online_url(act_id, app_id, module_id)
         launch_base_model = LaunchBaseModel(context=self)
+
         app_key, app_secret = self.get_app_key_secret()
-        invoke_result_data = launch_base_model.async_launch_goods(app_id, act_id, online_url, self.get_param("access_token"), app_key, app_secret)
+        invoke_result_data = launch_base_model.async_launch_goods(app_id, act_id, online_url, access_token, app_key, app_secret)
+        if invoke_result_data.success == False:
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
+        ref_params = {}
+        invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         return self.response_json_success()
\ No newline at end of file
