@@ -2,9 +2,9 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-02 14:25:02
-@LastEditTime: 2021-10-13 09:42:48
+@LastEditTime: 2022-06-14 14:08:41
 @LastEditors: HuangJianYi
-@Description: 
+@Description: 价格档位模块
 """
 from seven_cloudapp_frame.models.price_base_model import *
 from seven_cloudapp_frame.handlers.frame_base import *
@@ -16,7 +16,7 @@ class SavePriceGearHandler(ClientBaseHandler):
     """
     :description: 保存价格档位信息
     """
-    @filter_check_params("act_id,price")
+    @filter_check_params("price")
     def get_async(self):
         """
         :description: 保存价格档位
@@ -34,7 +34,7 @@ class SavePriceGearHandler(ClientBaseHandler):
         :last_editors: HuangJianYi
         """
         app_id = self.get_app_id()
-        act_id = int(self.get_param("act_id", 0))
+        act_id = self.get_act_id()
         price_gear_id = int(self.get_param("price_gear_id", 0))
         relation_type = int(self.get_param("relation_type", 1))
         price = self.get_param("price")
@@ -61,7 +61,6 @@ class PriceGearListHandler(ClientBaseHandler):
     """
     :description: 获取价格档位列表
     """
-    @filter_check_params("act_id")
     def get_async(self):
         """
         :description: 获取价格档位列表
@@ -74,12 +73,13 @@ class PriceGearListHandler(ClientBaseHandler):
         :last_editors: HuangJianYi
         """
         app_id = self.get_app_id()
-        act_id = int(self.get_param("act_id", 0))
+        act_id = self.get_act_id()
         page_index = int(self.get_param("page_index", 0))
         page_size = int(self.get_param("page_size", 20))
         is_del = int(self.get_param("is_del", 0))
-
-        return self.response_json_success(PriceBaseModel(context=self).get_price_gear_list(app_id, act_id, page_size, page_index,is_del=is_del,is_cache=False))
+        page_list, total = PriceBaseModel(context=self).get_price_gear_list(app_id, act_id, page_size, page_index, is_del=is_del, is_cache=False)
+        page_info = PageInfo(page_index, page_size, total, self.business_process_executed(page_list, ref_params={}))
+        return self.response_json_success(page_info)
 
 
 class DeletePriceGearHandler(ClientBaseHandler):
@@ -97,7 +97,7 @@ class DeletePriceGearHandler(ClientBaseHandler):
         :last_editors: HuangJianYi
         """
         app_id = self.get_app_id()
-        act_id = int(self.get_param("act_id", 0))
+        act_id = self.get_act_id()
         price_gear_id = int(self.get_param("price_gear_id", 0))
 
         price_base_model = PriceBaseModel(context=self)
@@ -123,7 +123,7 @@ class ReviewPriceGearHandler(ClientBaseHandler):
         :last_editors: HuangJianYi
         """
         app_id = self.get_app_id()
-        act_id = int(self.get_param("act_id", 0))
+        act_id = self.get_act_id()
         price_gear_id = int(self.get_param("price_gear_id", 0))
 
         price_base_model = PriceBaseModel(context=self)
@@ -138,7 +138,7 @@ class CheckPriceGearHandler(ClientBaseHandler):
     """
     :description: 验证价格档位
     """
-    @filter_check_params("act_id,goods_id")
+    @filter_check_params("goods_id")
     def get_async(self):
         """
         :description: 验证价格档位
@@ -151,7 +151,7 @@ class CheckPriceGearHandler(ClientBaseHandler):
         :last_editors: HuangJianYi
         """
         app_id = self.get_app_id()
-        act_id = int(self.get_param("act_id", 0))
+        act_id = self.get_act_id()
         price_gear_id = int(self.get_param("price_gear_id", 0))
         goods_id = self.get_param("goods_id")
         sku_id = self.get_param("sku_id")
