@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2022-03-10 14:05:22
-@LastEditTime: 2022-03-10 14:25:48
+@LastEditTime: 2022-05-31 11:27:27
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -71,9 +71,9 @@ class RedisExHelper:
         return result
 
     @classmethod
-    def acquire_lock(self, lock_name, acquire_time=3, time_out=4):
+    def acquire_lock(self, lock_name, acquire_time=5, time_out=10):
         """
-        :description: 创建分布式锁
+        :description: 创建分布式锁 基于setnx命令的特性，我们就可以实现一个最简单的分布式锁了。我们通过向Redis发送 setnx 命令，然后判断Redis返回的结果是否为1，结果是1就表示setnx成功了，那本次就获得锁了，可以继续执行业务逻辑；如果结果是0，则表示setnx失败了，那本次就没有获取到锁，可以通过循环的方式一直尝试获取锁，直至其他客户端释放了锁（delete掉key）后，就可以正常执行setnx命令获取到锁
         :param lock_name：锁定名称
         :param acquire_time: 客户端等待获取锁的时间,单位秒
         :param time_out: 锁的超时时间,单位秒
