@@ -2,13 +2,15 @@
 """
 :Author: HuangJianYi
 :Date: 2021-07-15 11:54:54
-@LastEditTime: 2022-04-27 13:42:04
+@LastEditTime: 2022-06-20 14:19:39
 @LastEditors: HuangJianYi
 :description: 常用帮助类
 """
 from seven_framework import *
 from seven_framework.redis import *
 from seven_cloudapp_frame.libs.customize.redis_helper import RedisExHelper
+from seven_cloudapp_frame.libs.customize.time_helper import TimeExHelper
+
 import random
 import datetime
 import re
@@ -299,8 +301,7 @@ class SevenHelper:
         :return: str
         :last_editors: HuangJianYi
         """
-        add_hours = config.get_value("add_hours", 0)
-        return TimeHelper.add_hours_by_format_time(hour=add_hours)
+        return TimeHelper.get_now_format_time()
 
     @classmethod
     def get_now_int(self, hours=0, minutes=0, fmt='%Y%m%d%H%M%S'):
@@ -312,8 +313,7 @@ class SevenHelper:
         :return:
         :last_editors: HuangJianYi
         """
-        now_date = (datetime.datetime.now() + datetime.timedelta(minutes=minutes, hours=hours))
-        return int(now_date.strftime(fmt))
+        return TimeExHelper.get_now_int(hours, minutes, fmt)
 
     @classmethod
     def get_now_hour_int(self, hours=0):
@@ -323,7 +323,7 @@ class SevenHelper:
         :return: int（2020050612）
         :last_editors: HuangJianYi
         """
-        return self.get_now_int(hours=hours, fmt='%Y%m%d%H')
+        return TimeExHelper.get_now_int(hours=hours, fmt='%Y%m%d%H')
 
     @classmethod
     def get_now_day_int(self, hours=0):
@@ -333,7 +333,7 @@ class SevenHelper:
         :return: int（20200506）
         :last_editors: HuangJianYi
         """
-        return self.get_now_int(hours=hours, fmt='%Y%m%d')
+        return TimeExHelper.get_now_int(hours=hours, fmt='%Y%m%d')
 
     @classmethod
     def get_now_month_int(self, hours=0):
@@ -343,7 +343,7 @@ class SevenHelper:
         :return: int（202005）
         :last_editors: HuangJianYi
         """
-        return self.get_now_int(hours=hours,fmt='%Y%m')
+        return TimeExHelper.get_now_int(hours=hours, fmt='%Y%m')
 
     @classmethod
     def get_date_list(self, start_date, end_date):
@@ -354,21 +354,7 @@ class SevenHelper:
         :return: list
         :last_editors: HuangJianYi
         """
-        if not start_date or not end_date:
-            return []
-        if ":" not in start_date:
-            start_date+=" 00:00:00"
-        if ":" not in end_date:
-            end_date += " 00:00:00"
-        datestart = datetime.datetime.strptime(start_date, '%Y-%m-%d %H:%M:%S')
-        dateend = datetime.datetime.strptime(end_date, '%Y-%m-%d %H:%M:%S')
-
-        date_list = []
-
-        while datestart < dateend:
-            date_list.append(datestart.strftime('%Y-%m-%d'))
-            datestart += datetime.timedelta(days=1)
-        return date_list
+        return TimeExHelper.get_date_list(start_date, end_date)
 
     @classmethod
     def get_page_count(self, page_size, record_count):
