@@ -2,13 +2,12 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-09 09:24:43
-@LastEditTime: 2022-04-28 15:05:14
+@LastEditTime: 2022-06-23 11:02:32
 @LastEditors: HuangJianYi
 @Description: 
 """
 from seven_cloudapp_frame.models.user_base_model import UserBaseModel
 from seven_cloudapp_frame.models.frame_base_model import FrameBaseModel
-from seven_cloudapp_frame.libs.customize.seven_helper import *
 from seven_cloudapp_frame.models.seven_model import *
 from seven_cloudapp_frame.models.app_base_model import *
 from seven_cloudapp_frame.models.top_base_model import *
@@ -16,10 +15,10 @@ from seven_cloudapp_frame.models.price_base_model import *
 from seven_cloudapp_frame.models.asset_base_model import *
 from seven_cloudapp_frame.models.db_models.act.act_module_model import *
 from seven_cloudapp_frame.models.db_models.prize.prize_order_model import *
-from seven_cloudapp_frame.models.db_models.prize.prize_order_model import *
 from seven_cloudapp_frame.models.db_models.prize.prize_roster_model import *
 from seven_cloudapp_frame.models.db_models.tao.tao_pay_order_model import *
 from seven_cloudapp_frame.models.db_models.user.user_info_model import *
+from seven_cloudapp_frame.models.db_models.tao.tao_coupon_model import *
 
 
 class OrderBaseModel(FrameBaseModel):
@@ -46,7 +45,6 @@ class OrderBaseModel(FrameBaseModel):
             dependency_key += f"_userid_{user_id}"
         PrizeOrderModel(sub_table=self.get_business_sub_table("prize_order_tb", {"act_id": act_id, "user_id": 0})).delete_dependency_key(dependency_key, delay_delete_time)
         
-
     def _delete_prize_roster_dependency_key(self, act_id, user_id, delay_delete_time=0.1):
         """
         :description: 删除中奖记录依赖建
@@ -62,7 +60,6 @@ class OrderBaseModel(FrameBaseModel):
         
         PrizeRosterModel(sub_table=self.get_business_sub_table("prize_roster_tb", {"act_id": act_id, "user_id": 0})).delete_dependency_key(dependency_key, delay_delete_time)
 
-
     def get_prize_order_list(self, app_id, act_id, user_id, open_id, nick_name, order_no, real_name, telephone, address, order_status, create_date_start, create_date_end, page_size=20, page_index=0, order_by="create_date desc", field="*", is_search_roster=False, is_cache=True, condition="", params=[], prize_roster_sub_table=None):
         """
         :description: 用户奖品订单列表
@@ -95,10 +92,11 @@ class OrderBaseModel(FrameBaseModel):
         if condition:
             where += " AND " + condition
             params_list.extend(params)
-        page_info = PageInfo(page_index, page_size, 0, [])
+        page_list = []
+        total = 0
 
         if not app_id or not act_id:
-            return page_info
+            return page_list, total
         if user_id:
             where += " AND user_id=%s"
             params_list.append(user_id)
@@ -148,8 +146,7 @@ class OrderBaseModel(FrameBaseModel):
                 for i in range(len(page_list)):
                     roster_list = [prize_roster for prize_roster in prize_roster_list_dict if page_list[i]["order_no"] == prize_roster["order_no"]]
                     page_list[i]["roster_list"] = roster_list
-        page_info = PageInfo(page_index, page_size, total, page_list)
-        return page_info
+        return page_list, total
 
     def update_prize_order_status(self,app_id,act_id,prize_order_id,order_status,express_company="",express_no="",prize_roster_sub_table=None):
         """
@@ -167,7 +164,7 @@ class OrderBaseModel(FrameBaseModel):
         if not prize_roster_sub_table:
             prize_roster_sub_table = self.get_business_sub_table("prize_roster_tb", {"act_id": act_id, "user_id": 0})
         now_datetime = SevenHelper.get_now_datetime()
-        db_transaction = DbTransaction(db_config_dict=config.get_value("db_cloudapp"))
+        db_transaction = DbTransaction(db_config_dict=config.get_value("db_cloudapp"),context=self.context)
         prize_order_model = PrizeOrderModel(sub_table=self.get_business_sub_table("prize_order_tb", {"act_id": act_id, "user_id": 0}),context=self.context, db_transaction=db_transaction)
         prize_roster_model = PrizeRosterModel(context=self.context, sub_table=prize_roster_sub_table, db_transaction=db_transaction)
         invoke_result_data = InvokeResultData()
@@ -202,12 +199,9 @@ class OrderBaseModel(FrameBaseModel):
                 prize_roster_model.update_table("logistics_status=2", "act_id=%s and order_no=%s", [prize_order.act_id,prize_order.order_no])
             else:
                 prize_order_model.update_table("order_status=%s,modify_date=%s", "id=%s", [order_status, now_datetime, prize_order_id])
-            result = db_transaction.commit_transaction()
+            result,message = db_transaction.commit_transaction(True)
             if result == False:
-                invoke_result_data.success = False
-                invoke_result_data.error_code = "error"
-                invoke_result_data.error_message ="操作失败"
-                return invoke_result_data
+                raise Exception("执行事务失败",message)
 
         except Exception as ex:
             if self.context:
@@ -342,53 +336,6 @@ class OrderBaseModel(FrameBaseModel):
         invoke_result_data.data = {"total_num": total_num}
         return invoke_result_data
 
-    def get_tao_pay_order_list(self,app_id,act_id,user_id,open_id,nick_name,pay_date_start,pay_date_end,page_size=20,page_index=0,field="*",order_by="pay_date desc",condition="",params=[]):
-        """
-        :description: 淘宝用户购买订单列表
-        :param app_id：应用标识
-        :param act_id：活动标识
-        :param user_id：用户唯一标识
-        :param open_id：open_id
-        :param nick_name：用户昵称
-        :param pay_date_start：订单支付时间开始
-        :param pay_date_end：订单支付时间结束
-        :param page_size：页大小
-        :param page_index：页索引
-        :param field：查询字段
-        :param order_by：排序
-        :param condition：条件
-        :param params：参数化数组
-        :return: PageInfo
-        :last_editors: HuangJianYi
-        """
-        where = "app_id=%s and act_id=%s"
-        params_list = [app_id,act_id]
-        if condition:
-            where += " AND " + condition
-            params_list.extend(params)
-        page_info = PageInfo(page_index, page_size, 0, [])
-
-        if not act_id:
-            return page_info
-        if user_id:
-            where += " AND user_id=%s"
-            params_list.append(user_id)
-        if open_id:
-            where += " AND open_id=%s"
-            params_list.append(open_id)
-        if nick_name:
-            where += " AND user_nick=%s"
-            params_list.append(nick_name)
-        if pay_date_start:
-            where += " AND pay_date>=%s"
-            params_list.append(pay_date_start)
-        if pay_date_end:
-            where += " AND pay_date<=%s"
-            params_list.append(pay_date_end)
-        page_list, total = TaoPayOrderModel(context=self.context).get_dict_page_list(field, page_index, page_size, where, "", order_by, params_list)
-        page_info = PageInfo(page_index, page_size, total, page_list)
-        return page_info
-
     def select_prize_order(self,app_id,act_id,user_id,login_token,prize_ids,real_name,telephone,province,city,county,street,address):
         """
         :description: 选择奖品进行下单
@@ -413,7 +360,7 @@ class OrderBaseModel(FrameBaseModel):
             invoke_result_data.error_code = "error"
             invoke_result_data.error_message ="无效活动,无法创建订单"
             return invoke_result_data
-        db_transaction = DbTransaction(db_config_dict=config.get_value("db_cloudapp"))
+        db_transaction = DbTransaction(db_config_dict=config.get_value("db_cloudapp"),context=self.context)
         user_info_model = UserInfoModel(db_transaction=db_transaction,sub_table=self.get_business_sub_table("user_info_tb", {"act_id": act_id, "user_id": 0}), context=self.context)
         prize_roster_model = PrizeRosterModel(db_transaction=db_transaction,sub_table=self.get_business_sub_table("prize_roster_tb", {"act_id": act_id, "user_id": 0}), context=self.context)
         prize_order_model = PrizeOrderModel(db_transaction=db_transaction,sub_table=self.get_business_sub_table("prize_order_tb", {"act_id": act_id, "user_id": 0}), context=self.context)
@@ -494,13 +441,9 @@ class OrderBaseModel(FrameBaseModel):
             db_transaction.begin_transaction()
             prize_order_model.add_entity(prize_order)
             prize_roster_model.update_list(prize_roster_list, "order_no,prize_status")
-            result = db_transaction.commit_transaction()
+            result,message = db_transaction.commit_transaction(True)
             if result == False:
-                invoke_result_data.success = False
-                invoke_result_data.error_code = "error"
-                invoke_result_data.error_message = "对不起,下单失败"
-                SevenHelper.redis_release_lock(acquire_lock_name, identifier)
-                return invoke_result_data
+                raise Exception("执行事务失败",message)
         except Exception as ex:
             if db_transaction.is_transaction == True:
                 db_transaction.rollback_transaction()
@@ -520,7 +463,54 @@ class OrderBaseModel(FrameBaseModel):
         invoke_result_data.data = prize_order.__dict__
         return invoke_result_data
 
-    def _get_pay_order_no_list(self,app_id,user_id):
+    def get_tao_pay_order_list(self,app_id,act_id,user_id,open_id,nick_name,pay_date_start,pay_date_end,page_size=20,page_index=0,field="*",order_by="pay_date desc",condition="",params=[]):
+        """
+        :description: 淘宝用户购买订单列表
+        :param app_id：应用标识
+        :param act_id：活动标识
+        :param user_id：用户唯一标识
+        :param open_id：open_id
+        :param nick_name：用户昵称
+        :param pay_date_start：订单支付时间开始
+        :param pay_date_end：订单支付时间结束
+        :param page_size：页大小
+        :param page_index：页索引
+        :param field：查询字段
+        :param order_by：排序
+        :param condition：条件
+        :param params：参数化数组
+        :return: PageInfo
+        :last_editors: HuangJianYi
+        """
+        where = "app_id=%s and act_id=%s"
+        params_list = [app_id,act_id]
+        if condition:
+            where += " AND " + condition
+            params_list.extend(params)
+        page_info = PageInfo(page_index, page_size, 0, [])
+
+        if not act_id:
+            return page_info
+        if user_id:
+            where += " AND user_id=%s"
+            params_list.append(user_id)
+        if open_id:
+            where += " AND open_id=%s"
+            params_list.append(open_id)
+        if nick_name:
+            where += " AND user_nick=%s"
+            params_list.append(nick_name)
+        if pay_date_start:
+            where += " AND pay_date>=%s"
+            params_list.append(pay_date_start)
+        if pay_date_end:
+            where += " AND pay_date<=%s"
+            params_list.append(pay_date_end)
+        page_list, total = TaoPayOrderModel(context=self.context).get_dict_page_list(field, page_index, page_size, where, "", order_by, params_list)
+        page_info = PageInfo(page_index, page_size, total, page_list)
+        return page_info
+
+    def _get_tao_pay_order_no_list(self,app_id,user_id):
         """
         :description: 获取已获取奖励的订单子编号列表
         :param app_id:应用标识
@@ -592,7 +582,7 @@ class OrderBaseModel(FrameBaseModel):
                     if invoke_result_data.success == True:
                         order_data = invoke_result_data.data
                 if len(order_data)>0:
-                    pay_order_no_list,redis_init,pay_order_cache_key = self._get_pay_order_no_list(app_id,user_id)
+                    pay_order_no_list,redis_init,pay_order_cache_key = self._get_tao_pay_order_no_list(app_id,user_id)
 
                     goods_ids_list = []
                     #满足奖励条件的订单
@@ -601,7 +591,7 @@ class OrderBaseModel(FrameBaseModel):
                     all_order_list = []
                     if asset_type == 3:
                         price_base_model = PriceBaseModel(context=self.context)
-                        price_gear_dict_list = price_base_model.get_price_gear_list(app_id,act_id,100,0).data
+                        price_gear_dict_list,total = price_base_model.get_price_gear_list(app_id,act_id,100,0)
                         for price_gear_dict in price_gear_dict_list:
                             goods_ids_list.append(price_gear_dict["goods_id"])
                     else:
@@ -907,3 +897,92 @@ class OrderBaseModel(FrameBaseModel):
                     prize_roster_list.append(prize_roster)
 
         return prize_roster_list
+
+    def get_coupon_prize(self, app_id, act_id, user_id, user_prize_id,is_log=False):
+        """
+        :description: 领取淘宝优惠券
+        :param app_id：应用标识
+        :param act_id：活动标识
+        :param user_id：用户标识
+        :param user_prize_id:用户奖品标识
+        :param is_log:是否记录日志
+        :return 
+        :last_editors: HuangJianYi
+        """
+        invoke_result_data = InvokeResultData()
+        app_base_model = AppBaseModel(context=self)
+        app_info_dict = app_base_model.get_app_info_dict(app_id)
+        if not app_info_dict:
+            invoke_result_data.success = False
+            invoke_result_data.error_code = "error"
+            invoke_result_data.error_message ="小程序不存在"
+            return invoke_result_data
+        access_token = app_info_dict["access_token"]
+        if access_token == "":
+            invoke_result_data.success = False
+            invoke_result_data.error_code = "error"
+            invoke_result_data.error_message ="未授权请联系客服授权"
+            return invoke_result_data
+        dependency_key = f"prize_roster_list:actid_{act_id}_userid_{user_id}"
+        frame_base_model = FrameBaseModel(context=self)
+        prize_roster_model = PrizeRosterModel(sub_table=frame_base_model.get_business_sub_table("prize_roster_tb", {"act_id": act_id, "user_id": 0}), context=self)
+        prize_roster_dict = prize_roster_model.get_cache_dict_by_id(user_prize_id, dependency_key=dependency_key)
+        if not prize_roster_dict or prize_roster_dict['user_id'] != user_id or prize_roster_dict['act_id'] != act_id:
+            invoke_result_data.success = False
+            invoke_result_data.error_code = "error"
+            invoke_result_data.error_message ="奖品不存在"
+            return invoke_result_data
+        tao_coupon_model = TaoCouponModel(context=self)
+        tao_coupon_dict = tao_coupon_model.get_dict(where="prize_id=%s", limit="1", params=[prize_roster_dict["prize_id"]])
+        if not tao_coupon_dict or tao_coupon_dict['right_ename'] == "":
+            invoke_result_data.success = False
+            invoke_result_data.error_code = "error"
+            invoke_result_data.error_message ="奖品不是优惠券,无需领取"
+            return invoke_result_data
+        top_base_model = TopBaseModel(context=self)
+        app_key,app_secret = self.get_app_key_secret()
+        top_invoke_result_data = top_base_model.alibaba_benefit_send(tao_coupon_dict['right_ename'], prize_roster_dict["open_id"], access_token, app_key, app_secret, is_log)
+        if top_invoke_result_data.success == False:
+            invoke_result_data.success = False
+            invoke_result_data.error_code = "error"
+            invoke_result_data.error_message ="领取失败"
+            return invoke_result_data
+        resp = top_invoke_result_data.data
+        if resp["alibaba_benefit_send_response"]:
+            if resp["alibaba_benefit_send_response"]["result_success"] == True:
+                prize_roster_model.update_table("prize_status=1", "id=%s", params=[user_prize_id])
+                prize_roster_model.delete_dependency_key(dependency_key)
+                result = {}
+                result["prize_name"] = resp["alibaba_benefit_send_response"]["prize_name"]
+                invoke_result_data.data = result
+                return invoke_result_data
+            if resp["alibaba_benefit_send_response"]["result_code"] == "COUPON_INVALID_OR_DELETED":
+                prize_roster_model.update_table("prize_status=10", "id=%s", params=[user_prize_id])
+                prize_roster_model.delete_dependency_key(dependency_key)
+                invoke_result_data.success = False
+                invoke_result_data.error_code = "error"
+                invoke_result_data.error_message ="领取失败：优惠券无效或已删除"
+                return invoke_result_data
+            if resp["alibaba_benefit_send_response"]["result_code"] == "APPLY_SINGLE_COUPON_COUNT_EXCEED_LIMIT":
+                invoke_result_data.success = False
+                invoke_result_data.error_code = "error"
+                invoke_result_data.error_message ="领取失败：优惠券超过限额"
+                return invoke_result_data
+            if resp["alibaba_benefit_send_response"]["result_code"] == "USER_PERMISSION_EXCEED_MAX_RIGHT_COUNT_IN_DAY":
+                invoke_result_data.success = False
+                invoke_result_data.error_code = "error"
+                invoke_result_data.error_message ="领取失败：同一张优惠券每天限领取一次"
+                return invoke_result_data
+            if resp["alibaba_benefit_send_response"]["result_code"] == "APPLY_ONE_SELLER_COUNT_EXCEED_LIMIT":
+                invoke_result_data.success = False
+                invoke_result_data.error_code = "error"
+                invoke_result_data.error_message ="领取失败：用户优惠券超出10张限制"
+                return invoke_result_data
+        else:
+            result = resp["sub_msg"] if resp["sub_msg"] else ""
+            if result == "" and resp["result_msg"]:
+                result = resp["result_msg"]
+            invoke_result_data.success = False
+            invoke_result_data.error_code = "error"
+            invoke_result_data.error_message = f"领取失败:{result}"
+            return invoke_result_data
\ No newline at end of file
