@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-02 14:26:29
-@LastEditTime: 2022-04-28 16:24:08
+@LastEditTime: 2022-06-14 14:06:29
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -148,8 +148,7 @@ class PriceBaseModel():
             page_list, total = price_gear_model.get_cache_dict_page_list(field="*", page_index=page_index, page_size=page_size, where=condition, group_by="", order_by=order_by,params=params,dependency_key=f"price_gear_list:actid_{act_id}")
         else:
             page_list, total = price_gear_model.get_dict_page_list(field="*", page_index=page_index, page_size=page_size, where=condition, group_by="", order_by=order_by,params=params)
-        page_info = PageInfo(page_index, page_size, total, page_list)
-        return page_info
+        return page_list, total
 
     def update_price_gear_status(self,app_id,act_id,price_gear_id,is_del):
         """
