@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-05-02 15:17:41
-@LastEditTime: 2021-09-17 15:16:17
+@LastEditTime: 2021-12-29 17:57:33
 @LastEditors: HuangJianYi
 :description: 自定义实体模型
 """
@@ -10,7 +10,6 @@
 class InvokeResult():
     """
     :description: 接口返回实体
-    :param {type} 
     :return: InvokeResult
     :last_editors: HuangJianYi
     """
@@ -22,8 +21,7 @@ class InvokeResult():
 class InvokeResultData():
     """
     :description: 接口返回实体
-    :param {type} 
-    :return: 
+    :return: InvokeResultData
     :last_editors: HuangJianYi
     """
     def __init__(self):
@@ -36,7 +34,6 @@ class InvokeResultData():
 class FileUploadInfo():
     """
     :description: 文件上传信息实体
-    :param {type} 
     :return: FileUploadInfo
     :last_editors: HuangJianYi
     """
@@ -116,3 +113,30 @@ class PageInfo():
         self.is_previous = True
         if page_index == 0:
             self.is_previous = False
+
+
+class ConditionWhere():
+    """
+    @description: 条件拼接实体
+    """
+    def __init__(self):
+        
+        self.condition_list = []
+
+    def add_condition(self, condition):
+        """
+        :description: 添加条件
+        :param condition:条件
+        :return:
+        :last_editors: HuangJianYi
+        """
+        self.condition_list.append(condition)
+
+    def to_string(self, split_str="and"):
+        """
+        :description: 拼接成字符串
+        :param split_str:分隔符
+        :return:
+        :last_editors: HuangJianYi
+        """
+        return str(" " + split_str + " ").join(self.condition_list)
\ No newline at end of file
