@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-22 11:10:20
-@LastEditTime: 2022-05-31 15:13:50
+@LastEditTime: 2022-06-07 09:35:59
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -211,7 +211,7 @@ class UserBaseModel(FrameBaseModel):
         user_info_model = UserInfoModel(sub_table=self.get_business_sub_table("user_info_tb", {"act_id": act_id, "user_id": 0}),context=self.context)
         now_datetime = SevenHelper.get_now_datetime()
         try:
-            user_account = user_account_model.get_cache_entity("open_id=%s", params=[open_id], dependency_key=f"user_account:openid_{open_id}")
+            user_account = user_account_model.get_entity("open_id=%s", params=[open_id])
             if not user_account:
                 user_account = UserAccount()
                 user_account.union_id = union_id
@@ -227,10 +227,13 @@ class UserBaseModel(FrameBaseModel):
                 if user_nick and user_account.user_nick != user_nick:
                     user_account.user_nick = CryptographyHelper.emoji_to_emoji_base64(user_nick)
                     user_account.user_nick_encrypt = CryptographyHelper.base64_encrypt(user_nick)
-                user_account.avatar = avatar if avatar and user_account.avatar != avatar else user_account.avatar
-                user_account_model.update_entity(user_account, "user_nick,user_nick_encrypt,avatar")
+                if avatar and user_account.avatar != avatar:
+                    user_account.avatar = avatar
+                if union_id and user_account.union_id != union_id:
+                    user_account.union_id = union_id
+                user_account_model.update_entity(user_account, "user_nick,user_nick_encrypt,avatar,union_id")
 
-            user_info = user_info_model.get_cache_entity("act_id=%s and open_id=%s", params=[act_id, open_id], dependency_key=self.get_user_info_dependency_key(act_id,"",open_id))
+            user_info = user_info_model.get_entity("act_id=%s and open_id=%s", params=[act_id, open_id])
             if not user_info:
                 user_info = UserInfo()
                 user_info.id_md5 = self._get_user_info_id_md5(act_id, user_account.id)
@@ -238,6 +241,7 @@ class UserBaseModel(FrameBaseModel):
                 user_info.act_id = act_id
                 user_info.open_id = open_id
                 user_info.user_id = user_account.id
+                user_info.union_id = user_account.union_id
                 user_info.is_new = 1
                 user_info.user_nick = user_account.user_nick
                 user_info.user_nick_encrypt = user_account.user_nick_encrypt
@@ -254,6 +258,7 @@ class UserBaseModel(FrameBaseModel):
                     invoke_result_data.error_code = "error"
                     invoke_result_data.error_message = "非法操作"
                     return invoke_result_data
+                user_info.union_id = user_account.union_id
                 user_info.user_nick = user_account.user_nick
                 user_info.user_nick_encrypt = user_account.user_nick_encrypt
                 user_info.avatar = user_account.avatar
@@ -263,9 +268,8 @@ class UserBaseModel(FrameBaseModel):
                 user_info.is_new = 0
                 user_info.modify_date = now_datetime
                 user_info.login_token = SevenHelper.get_random(16)
-                user_info_model.update_entity(user_info, "modify_date,login_token,is_new,user_nick,user_nick_encrypt,avatar,is_auth")
-
-                user_info_model.delete_dependency_key([f"user_account:openid_{open_id}",self.get_user_info_dependency_key(act_id, user_info.id_md5), self.get_user_info_dependency_key(act_id, "", user_info.open_id)])
+                user_info_model.update_entity(user_info, "modify_date,login_token,is_new,user_nick,user_nick_encrypt,avatar,is_auth,union_id")
+                user_info_model.delete_dependency_key([self.get_user_info_dependency_key(act_id, user_info.id_md5), self.get_user_info_dependency_key(act_id, "", user_info.open_id)])
 
         except Exception as ex:
             if self.context:
@@ -342,6 +346,7 @@ class UserBaseModel(FrameBaseModel):
                 params.append(user_info_dict["user_id"])
                 if update_sql:
                     user_account_model.update_table(update_sql, "id=%s", params=params)
+                    user_account_model.delete_dependency_key(f"user_account:openid_" + user_info_dict["open_id"])
 
         except Exception as ex:
             if self.context:
@@ -764,12 +769,15 @@ class UserBaseModel(FrameBaseModel):
         :return: 
         :last_editors: HuangJianYi
         """
+        user_address_list = []
+        if not act_id or not user_id:
+            return user_address_list
         condition = "act_id=%s AND user_id=%s"
         params = [act_id, user_id]
         if app_id:
             condition += " AND app_id=%s"
             params.append(app_id)
-        user_address_list = []
+        
         user_address_model = UserAddressModel(context=self.context)
         if is_cache:
             user_address_list = user_address_model.get_cache_dict_list(condition, limit="100", params=params, dependency_key=f"user_address_list:actid_{act_id}_userid_{user_id}")
